@@ -1,18 +1,18 @@
-set rcsId {$Id: bindings.tcl,v 1.5 1998/10/25 14:03:58 jfontain Exp $}
+# $Id: bindings.tcl,v 2.3 2002/05/30 17:13:10 jfontain Exp $
 
 # provide a reliable non-intrusive binding mechanism: a new tag is created, inserted in the existing tags at a specified position
 # and when deleted, all existing bndings for this tag are safely and completely removed
 
 class bindings {
     proc bindings {this widget index} {
-        ::set bindings::($this,widget) $widget
+        ::set ($this,widget) $widget
         bindtags $widget [linsert [bindtags $widget] $index bindings($this)]
     }
     proc ~bindings {this} {
-        if {![winfo exists bindings::($this,widget)]} return
-        ::set tags [bindtags $bindings::($this,widget)]
+        if {![winfo exists $($this,widget)]} return
+        ::set tags [bindtags $($this,widget)]
         ::set index [lsearch -exact $tags bindings($this)]
-        bindtags $bindings::($this,widget) [lreplace $tags $index $index]
+        bindtags $($this,widget) [lreplace $tags $index $index]
         foreach tag [bind bindings($this)] {
             bind bindings($this) $tag {}
         }
