@@ -1,4 +1,5 @@
-set rcsId {$Id: confint.tcl,v 1.31 1998/11/14 20:05:37 jfontain Exp $}
+set rcsId {$Id: confint.tcl,v 2.2 2000/11/01 12:02:41 jfontain Exp $}
+
 
 # minimalist composite widget configuration interface for widget testing and HTML live documentation with configuration applet
 
@@ -28,10 +29,10 @@ proc configurationInterface::~configurationInterface {this} {
 proc configurationInterface::options {this} {}
 
 proc configurationInterface::manage {this widget} {
-    if {[info exists configurationInterface::($this,managed)]} {
+    if {[info exists ($this,managed)]} {
         error "a widget \"$widget\" of class [classof $widget] is managed already"
     }
-    set configurationInterface::($this,managed) $widget
+    set ($this,managed) $widget
     # build a list of widget names with parenthesized class (this represents the composite widget itself)
     set list this([string trimleft [classof $widget] :])
     foreach name [composite::componentNames $widget] {
@@ -51,8 +52,8 @@ proc configurationInterface::update {this} {
         return
     }
     scan [lindex [$composite::($this,names,path) get $selection] 0] {%[^(]} name                  ;# ignore parenthesized class name
-    set managed $configurationInterface::($this,managed)
-    if {[string compare $name this]==0} {
+    set managed $($this,managed)
+    if {[string equal $name this]} {
         updateOptionEntries $this $managed
     } else {
         updateOptionEntries $this $composite::($managed,$name)
@@ -62,16 +63,16 @@ proc configurationInterface::update {this} {
 }
 
 proc configurationInterface::updateOptionEntries {this widget {columns 2}} {
-    if {[info exists configurationInterface::($this,entriesPath)]} {
+    if {[info exists ($this,entriesPath)]} {
         scroller::display $composite::($this,scroller) {}
-        destroy $configurationInterface::($this,entriesPath)
+        destroy $($this,entriesPath)
     }
-    set configurationInterface::($this,entriesPath) [set frame [frame $composite::($this,scroller,path).entries]]
+    set ($this,entriesPath) [set frame [frame $composite::($this,scroller,path).entries]]
     set columns [expr {2*$columns}]
     set column 0
     set row 0
     foreach description [widget::configure $widget] {
-        if {[llength $description]<4} {
+        if {[llength $description]<2} {
             continue                                                                                     ;# skip abbreviated options
         }
         set option [string trimleft [lindex $description 0] -]
